import os
import unittest
from pyats.topology import loader
from genie.libs.sdk.apis.iosxe.bgp.configure import get_running_config_section_dict


class TestGetRunningConfigSectionDict(unittest.TestCase):

    @classmethod
    def setUpClass(self):
        testbed = f"""
        devices:
          IR1101:
            connections:
              defaults:
                class: unicon.Unicon
              a:
                command: mock_device_cli --os iosxe --mock_data_dir {os.path.dirname(__file__)}/mock_data --state connect
                protocol: unknown
            os: iosxe
            platform: router
            type: router
        """
        self.testbed = loader.load(testbed)
        self.device = self.testbed.devices['IR1101']
        self.device.connect(
            learn_hostname=True,
            init_config_commands=[],
            init_exec_commands=[]
        )

    def test_get_running_config_section_dict(self):
        result = get_running_config_section_dict(self.device)
        expected_output = {'Building configuration...': {},
 'Current configuration : 8848 bytes': {},
 'aaa accounting auth-proxy default start-stop group radius': {},
 'aaa accounting dot1x default start-stop group radius': {},
 'aaa authentication dot1x default group radius': {},
 'aaa authentication login CON local': {},
 'aaa authentication login VTY local': {},
 'aaa authorization auth-proxy default group radius': {},
 'aaa authorization network default group radius': {},
 'aaa new-model': {},
 'aaa session-id common': {},
 'boot system bootflash:ir1101-universalk9.2024-08-19_16.16_flian.SSA.bin': {},
 'boot-end-marker': {},
 'boot-start-marker': {},
 'bridge-domain 12': {'member Vlan12 service-instance 12': {},
                      'member evpn-instance profile evpn_va': {}},
 'bridge-domain 20': {'member Vlan20 service-instance 20': {},
                      'member evpn-instance': {}},
 'bridge-domain 21': {'member Vlan21 service-instance 21': {},
                      'member evpn-instance': {}},
 'bridge-domain 22': {'member Vlan22 service-instance 22': {},
                      'member evpn-instance profile evpn_va': {}},
 'control-plane': {},
 'controller Cellular 0/1/0': {},
 'controller Cellular 0/4/0': {},
 'crypto pki certificate chain SLA-TrustPoint': {'certificate ca 01': {'005A282F 8B518A5A 8C6F9B3C AABA3446 32EF3A75 C2F45450 7A9BCFD3 0C8BE54A': {},
                                                                       '01009C56 7101D61E DF2EBCC3 BA7AE0DB B241B3B4 328A9B00 EB8A80D0 2AA86F5E': {},
                                                                       '01C50203 010001A3 42304030 0E060355 1D0F0101 FF040403 02010630 0F060355': {},
                                                                       '07B2BDED DFC1605B 4D16007B 68723E25 55908512 4EEB0A70 B2A74C2A CB1EC882': {},
                                                                       '11872DE0 CF1200D0 D1018FD9 AC685968 167E421C 9BC394ED 9BC85463 83B28146': {},
                                                                       '179196FA 4FB3F2ED 3942C756 BF1CA0A9 CC98A7A7 F9E43724 D9E61D47 89E9E792': {},
                                                                       '1D130101 FF040530 030101FF 301D0603 551D0E04 16041443 214521B5 FB217A1A': {},
                                                                       '2F310E30 0C060355 040A1305 43697363 6F311D30 1B060355 04031314 4C696365': {},
                                                                       '3082031B 30820203 A0030201 02020101 300D0609 2A864886 F70D0101 0B050030': {},
                                                                       '3EBC1385 2D9BAD98 68D3AE07 5C27987C 6B814B99 0686B14A 5F61753C 813089E6': {},
                                                                       '4D1BB702 36E664CB EC8B6530 0D06092A 864886F7 0D01010B 05000382 01010085': {},
                                                                       '56308201 22300D06 092A8648 86F70D01 01010500 0382010F 00308201 0A028201': {},
                                                                       '5A170D33 33303432 34323135 3534335A 302F310E 300C0603 55040A13 05436973': {},
                                                                       '636F311D 301B0603 55040313 144C6963 656E7369 6E672052 6F6F7420 2D204445': {},
                                                                       '6D081172 26916B41 FB07DF42 EB9B9408 EC346138 23FBD8C4 19909697 A30845F3': {},
                                                                       '6E73696E 6720526F 6F74202D 20444556 301E170D 31333034 32343231 35353433': {},
                                                                       '7CE521B5 F277EBF6 03B7B0A4 958C9C7D 5460C20B CF9CCFC7 14B80F58 B5268947': {},
                                                                       'AEC48C68 F6D45267 0E365F44 B4456E11 96DCB950 233C8ADB 9FEEBAF1 2B5F3BB6': {},
                                                                       'C3215B87 6FC74304 241E59D7 C7C02C6D BD3042F5 196E8133 7A4446A4 81216E70': {},
                                                                       'CF52CF22 50A7D23E FA9F6B07 FB0F6386 9DCC3BBC 65250693 38CF6BA6 CB8EFD': {'quit': {}},
                                                                       'DD9F27B4 517C2BDE D0EB5B9A 787BA085 D9BBF003 F0563BE0 A4450C8F 127B5583': {},
                                                                       'DF07E06C AA0F4325 9FB4C4AE 2080F675 8C3B7AC5 4EAAA03E C5B50A2F 670AFF87': {},
                                                                       'EDA6462F CFC43967 C024AB32 EE3CCDCF A04B9DAE 1BBABBDA C8DF5587 CF51CB1C': {},
                                                                       'F1AEBFDE B67BD6AD 7DAD7B43 F582753B FFCC1CA5 A7841A07 6934D3AF 99078EF6': {},
                                                                       'F1B1F2AE AE7D2F9C AB0351C3 29E3F1AE 982DF11F 5E3C90F6 00B3CDED 5A1491FB': {}}},
 'crypto pki certificate chain TP-self-signed-79755127': {'certificate self-signed 01': {'010096BD FA5EC31E E1CA26D1 D1A94236 53C2676C CBA0B127 950659A7 4E30333A': {},
                                                                                         '040FEB98 AACD013C 0219E81C A17B3165 BC6E293F 8C99A03E 19B1B20B F819DBD3': {},
                                                                                         '06D462F5 7FF006E8 61B060DB 4F5C448A 7F665ED3 36E4F72A D3C211B2 6D02D27E': {},
                                                                                         '0E2F09E5 0003CF83 24D0F290 71633F0E 3FCA406A 6E973955 D62A886D 38D3E72B': {},
                                                                                         '0F3A9E56 43799614 71ADA617 A965FA8F 34CB72C6 C08B7317 A2F14949 5EF4B26B': {},
                                                                                         '2A864886 F70D0101 0D050003 82010100 38DACAB7 4A785C4C 31DCB300 1A2059B1': {},
                                                                                         '2D53656C 662D5369 676E6564 2D436572 74696669 63617465 2D373937 35353132': {},
                                                                                         '2F312D30 2B060355 04030C24 494F532D 53656C66 2D536967 6E65642D 43657274': {},
                                                                                         '3082032C 30820214 A0030201 02020101 300D0609 2A864886 F70D0101 0D050030': {},
                                                                                         '30ECB57C 9DAC16E8 F78C4B30 0F060355 1D130101 FF040530 030101FF 300D0609': {},
                                                                                         '37308201 22300D06 092A8648 86F70D01 01010500 0382010F 00308201 0A028201': {},
                                                                                         '3BAB97FE 6C52EFBB 1BCBC620 ED88716D 62C32FB9 D7CB201C 44383EEB ADF9EC7E': {},
                                                                                         '56710203 010001A3 53305130 1D060355 1D0E0416 0414CDFE 54823321 E5288730': {},
                                                                                         '57E40B34 5D13765B CB30AB97 322896F2 D58C6FC7 97881B0F 02494695 28067056': {},
                                                                                         '5A170D33 34303831 31303430 3432385A 302F312D 302B0603 5504030C 24494F53': {},
                                                                                         '5ED1F03D 5D862072 0FC2BE97 E02C149C 5A6953E7 54F80ED6 A367C749 5202FC26': {},
                                                                                         '69666963 6174652D 37393735 35313237 301E170D 32343038 31313034 30343238': {},
                                                                                         '7F7CDDC6 D40F7CB5 6743D168 31625D2B': {'quit': {}},
                                                                                         '7FF00828 1D1B290A 552A7D90 F7F6BFDF DBE9146E 7A0A7261 A48BF507 C724D80C': {},
                                                                                         '8BC33D8A EC579C44 75DD9462 3AC80735 D548CFD1 72E59516 2DC268F5 5F578897': {},
                                                                                         '9EC0EBB3 00905472 28782737 324C6084 3B442E60 CDE7733A 9CE57C53 494B9353': {},
                                                                                         'ADC0EEF7 E110E2B3 90CFD773 FD172613 CFDB5BFA 986129C4 BF27264D 63B30B5C': {},
                                                                                         'D494F855 8AEE9D74 2211CE08 BBB475A9 E6C19D2F 18F3028E D05D766D 0914DC02': {},
                                                                                         'DE77BF86 623303CF 419A6423 D8DE02AF 51C0525A F5C7A823 78475D78 EFBB5A0F': {},
                                                                                         'ECB57C9D AC16E8F7 8C4B301F 0603551D 23041830 168014CD FE548233 21E52887': {},
                                                                                         'F470DCB4 DAC377C5 38AAF646 32A72DE3 111FCA7E 5B72A3F8 56A1186B A410D8E2': {}}},
 'crypto pki trustpoint SLA-TrustPoint': {'enrollment pkcs12': {},
                                          'hash sha512': {},
                                          'revocation-check crl': {}},
 'crypto pki trustpoint TP-self-signed-79755127': {'enrollment selfsigned': {},
                                                   'hash sha256': {},
                                                   'revocation-check none': {},
                                                   'rsakeypair TP-self-signed-79755127': {},
                                                   'subject-name cn=IOS-Self-Signed-Certificate-79755127': {}},
 'diagnostic bootup level minimal': {},
 'end': {},
 'hostname IR1101': {},
 'interface Async0/2/0': {'encapsulation scada': {}, 'no ip address': {}},
 'interface Cellular0/1/0': {'ip address negotiated': {}, 'ipv6 enable': {}},
 'interface Cellular0/1/1': {'no ip address': {}, 'shutdown': {}},
 'interface Cellular0/4/0': {'no ip address': {}, 'shutdown': {}},
 'interface Cellular0/4/1': {'no ip address': {}, 'shutdown': {}},
 'interface FastEthernet0/0/1': {'authentication open': {},
                                 'authentication order mab': {},
                                 'authentication port-control auto': {},
                                 'dot1x pae authenticator': {},
                                 'evpn ethernet-segment 1': {},
                                 'mab': {},
                                 'spanning-tree portfast': {},
                                 'switchport access vlan 20': {},
                                 'switchport mode trunk': {},
                                 'switchport trunk allowed vlan 20,21,30': {},
                                 'switchport voice vlan 117': {}},
 'interface FastEthernet0/0/2': {'switchport access vlan 11': {},
                                 'switchport mode access': {}},
 'interface FastEthernet0/0/3': {'spanning-tree portfast': {},
                                 'switchport access vlan 10': {},
                                 'switchport voice vlan 117': {}},
 'interface FastEthernet0/0/4': {},
 'interface GigabitEthernet0/0/0': {'ip address 10.10.10.2 255.255.255.0': {}},
 'interface Loopback0': {'ip address 100.100.100.1 255.255.255.255': {}},
 'interface Vlan1': {'no ip address': {}},
 'interface Vlan11': {'ip address 11.1.6.78 255.255.255.0': {}},
 'interface Vlan12': {'no ip address': {},
                      'service instance 12 ethernet': {'encapsulation dot1q 12': {}}},
 'interface Vlan20': {'no ip address': {},
                      'service instance 20 ethernet': {'encapsulation dot1q 20': {}}},
 'interface Vlan21': {'no ip address': {},
                      'service instance 21 ethernet': {'encapsulation dot1q 21': {}}},
 'interface Vlan22': {'no ip address': {},
                      'service instance 22 ethernet': {'encapsulation dot1q 22': {}}},
 'interface nve1': {'host-reachability protocol bgp': {},
                    'member vni 30000 ingress-replication': {},
                    'no ip address': {},
                    'source-interface Loopback0': {}},
 'ip forward-protocol nd': {},
 'ip http auth-retry 3 time-window 1': {},
 'ip http authentication local': {},
 'ip http secure-server': {},
 'ip ssh bulk-mode 131072': {},
 'l2vpn evpn': {'replication-type ingress': {}},
 'l2vpn evpn ethernet-segment 1': {'identifier type 0 0A.0A.0A.0A.0A.0A.0A.0A.0A': {},
                                   'redundancy all-active': {}},
 'l2vpn evpn ethernet-segment 2': {'identifier type 3 system-mac 0020.bbbb.bbbb': {},
                                   'redundancy all-active': {}},
 'l2vpn evpn instance 1 vlan-aware': {'encapsulation vxlan': {},
                                      'replication-type ingress': {}},
 'l2vpn evpn profile evpn_va vlan-aware': {'ethernet-tag auto-vni': {},
                                           'evi-id 3': {},
                                           'l2vni-base 50000': {}},
 'license udi pid IR1101-K9 sn FCW2804Y6L5': {},
 'line 0/0/0': {},
 'line 0/2/0': {},
 'line con 0': {'exec-timeout 0 0': {}, 'stopbits 1': {}},
 'line vty 0 4': {'exec-timeout 0 0': {}, 'transport input ssh': {}},
 'line vty 5 14': {'transport input ssh': {}},
 'login block-for 60 attempts 3 within 30': {},
 'login delay 3': {},
 'login on-success log': {},
 'memory free low-watermark processor 43390': {},
 'no ip forward-protocol udp': {},
 'no ip http server': {},
 'no license feature hseck9': {},
 'no logging console': {},
 'platform hardware msata-led': {},
 'platform hardware throughput level 250M': {},
 'platform qfp utilization monitor load 80': {},
 'redundancy': {},
 'router bgp 1': {'address-family ipv4': {'neighbor 100.100.100.4 activate': {},
                                          'neighbor 100.100.100.4 send-community both': {}},
                  'address-family l2vpn evpn': {'neighbor 100.100.100.4 activate': {},
                                                'neighbor 100.100.100.4 send-community both': {}},
                  'address-family l2vpn vpls': {},
                  'bgp log-neighbor-changes': {},
                  'bgp router-id 100.100.100.1': {},
                  'exit-address-family': {},
                  'neighbor 100.100.100.4 remote-as 1': {},
                  'neighbor 100.100.100.4 update-source Loopback0': {}},
 'router ospf 1': {'network 10.10.10.0 0.0.0.255 area 0': {},
                   'network 100.100.100.1 0.0.0.0 area 0': {},
                   'router-id 100.100.100.1': {}},
 'service timestamps debug datetime msec': {},
 'service timestamps log datetime msec': {},
 'spanning-tree extend system-id': {},
 'subscriber templating': {},
 'version 17.16': {},
 'vlan internal allocation policy ascending': {},
 'yang-interfaces feature deprecated disable': {}}
        self.assertEqual(result, expected_output)
