import os
import unittest
from pyats.topology import loader
from genie.libs.sdk.apis.iosxe.inventory.get import get_component_descr


class TestGetComponentDescr(unittest.TestCase):

    @classmethod
    def setUpClass(self):
        testbed = f"""
        devices:
          Switch:
            connections:
              defaults:
                class: unicon.Unicon
              a:
                command: mock_device_cli --os iosxe --mock_data_dir {os.path.dirname(__file__)}/mock_data --state connect
                protocol: unknown
            os: iosxe
            platform: cat9k
            type: iosxe
        """
        self.testbed = loader.load(testbed)
        self.device = self.testbed.devices['Switch']
        self.device.connect(
            learn_hostname=True,
            init_config_commands=[],
            init_exec_commands=[]
        )

    def test_get_component_descr(self):
        result = get_component_descr(self.device)
        expected_output = {'descr': ['Cisco Catalyst 9400 Series 7 Slot Chassis',
           'Cisco Catalyst 9400 Series 7 Slot Chassis Backplane',
           'Cisco Catalyst 9400 Series Carrier Card Module Container',
           'Cisco Catalyst 9400 Series 48-Port UPOE 10/100/1000 (RJ-45)',
           'V1: VX1',
           'V1: VX2',
           'V1: VX3',
           'V1: VX4',
           'V1: VX5',
           'V1: VX6',
           'V1: VX7',
           'V1: VX8',
           'V1: VX9',
           'V1: VX10',
           'V1: VX11',
           'Temp:   Outlet',
           'Temp:    Inlet',
           'HotSwap: Volts',
           'HotSwap: Power',
           'GigabitEthernet1/0/1',
           'GigabitEthernet1/0/2',
           'GigabitEthernet1/0/3',
           'GigabitEthernet1/0/4',
           'GigabitEthernet1/0/5',
           'GigabitEthernet1/0/6',
           'GigabitEthernet1/0/7',
           'GigabitEthernet1/0/8',
           'GigabitEthernet1/0/9',
           'GigabitEthernet1/0/10',
           'GigabitEthernet1/0/11',
           'GigabitEthernet1/0/12',
           'GigabitEthernet1/0/13',
           'GigabitEthernet1/0/14',
           'GigabitEthernet1/0/15',
           'GigabitEthernet1/0/16',
           'GigabitEthernet1/0/17',
           'GigabitEthernet1/0/18',
           'GigabitEthernet1/0/19',
           'GigabitEthernet1/0/20',
           'GigabitEthernet1/0/21',
           'GigabitEthernet1/0/22',
           'GigabitEthernet1/0/23',
           'GigabitEthernet1/0/24',
           'GigabitEthernet1/0/25',
           'GigabitEthernet1/0/26',
           'GigabitEthernet1/0/27',
           'GigabitEthernet1/0/28',
           'GigabitEthernet1/0/29',
           'GigabitEthernet1/0/30',
           'GigabitEthernet1/0/31',
           'GigabitEthernet1/0/32',
           'GigabitEthernet1/0/33',
           'GigabitEthernet1/0/34',
           'GigabitEthernet1/0/35',
           'GigabitEthernet1/0/36',
           'GigabitEthernet1/0/37',
           'GigabitEthernet1/0/38',
           'GigabitEthernet1/0/39',
           'GigabitEthernet1/0/40',
           'GigabitEthernet1/0/41',
           'GigabitEthernet1/0/42',
           'GigabitEthernet1/0/43',
           'GigabitEthernet1/0/44',
           'GigabitEthernet1/0/45',
           'GigabitEthernet1/0/46',
           'GigabitEthernet1/0/47',
           'GigabitEthernet1/0/48',
           'Cisco Catalyst 9400 Series Carrier Card Module Container',
           'Cisco Catalyst 9400 Series 48-Port UPOE 10/100/1000 (RJ-45)',
           'V1: VX1',
           'V1: VX2',
           'V1: VX3',
           'V1: VX4',
           'V1: VX5',
           'V1: VX6',
           'V1: VX7',
           'V1: VX8',
           'V1: VX9',
           'V1: VX10',
           'V1: VX11',
           'Temp:   Outlet',
           'Temp:    Inlet',
           'HotSwap: Volts',
           'HotSwap: Power',
           'GigabitEthernet2/0/1',
           'GigabitEthernet2/0/2',
           'GigabitEthernet2/0/3',
           'GigabitEthernet2/0/4',
           'GigabitEthernet2/0/5',
           'GigabitEthernet2/0/6',
           'GigabitEthernet2/0/7',
           'GigabitEthernet2/0/8',
           'GigabitEthernet2/0/9',
           'GigabitEthernet2/0/10',
           'GigabitEthernet2/0/11',
           'GigabitEthernet2/0/12',
           'GigabitEthernet2/0/13',
           'GigabitEthernet2/0/14',
           'GigabitEthernet2/0/15',
           'GigabitEthernet2/0/16',
           'GigabitEthernet2/0/17',
           'GigabitEthernet2/0/18',
           'GigabitEthernet2/0/19',
           'GigabitEthernet2/0/20',
           'GigabitEthernet2/0/21',
           'GigabitEthernet2/0/22',
           'GigabitEthernet2/0/23',
           'GigabitEthernet2/0/24',
           'GigabitEthernet2/0/25',
           'GigabitEthernet2/0/26',
           'GigabitEthernet2/0/27',
           'GigabitEthernet2/0/28',
           'GigabitEthernet2/0/29',
           'GigabitEthernet2/0/30',
           'GigabitEthernet2/0/31',
           'GigabitEthernet2/0/32',
           'GigabitEthernet2/0/33',
           'GigabitEthernet2/0/34',
           'GigabitEthernet2/0/35',
           'GigabitEthernet2/0/36',
           'GigabitEthernet2/0/37',
           'GigabitEthernet2/0/38',
           'GigabitEthernet2/0/39',
           'GigabitEthernet2/0/40',
           'GigabitEthernet2/0/41',
           'GigabitEthernet2/0/42',
           'GigabitEthernet2/0/43',
           'GigabitEthernet2/0/44',
           'GigabitEthernet2/0/45',
           'GigabitEthernet2/0/46',
           'GigabitEthernet2/0/47',
           'GigabitEthernet2/0/48',
           'Cisco Catalyst 9400 Series Carrier Card Module Container',
           'Cisco Catalyst 9400 Series Carrier Card Module Container',
           'Cisco Catalyst 9400 Series Carrier Card Module Container',
           'Cisco Catalyst 9400 Series Carrier Card Module Container',
           'Cisco Catalyst 9400 Series Carrier Card Module Container',
           'Cisco Catalyst 9400 Series Routing Processor Module Container',
           'Cisco Catalyst 9400 Series Supervisor 1 Module',
           'USB Container',
           'SATA Container',
           'TenGigabitEthernet3/0/1 Container',
           '10G AOC10M',
           'TenGigabitEthernet3/0/2 Container',
           'TenGigabitEthernet3/0/3 Container',
           'TenGigabitEthernet3/0/4 Container',
           'TenGigabitEthernet3/0/5 Container',
           'TenGigabitEthernet3/0/6 Container',
           'TenGigabitEthernet3/0/7 Container',
           'TenGigabitEthernet3/0/8 Container',
           'FortyGigabitEthernet3/0/9 Container',
           'FortyGigabitEthernet3/0/10 Container',
           'AppGigabitEthernet3/0/1 Container',
           'Temp: Coretemp',
           'Temp: UADP',
           'V1: VX1',
           'V1: VX2',
           'V1: VX3',
           'V1: VX4',
           'V1: VX5',
           'V1: VX6',
           'V1: VX7',
           'V1: VX8',
           'V1: VX9',
           'V1: VX10',
           'V1: VX11',
           'V1: VX12',
           'V1: VX13',
           'V1: VX14',
           'V1: VX15',
           'V1: VX16',
           'Temp:   outlet',
           'Temp:    inlet',
           'HotSwap: Volts',
           'HotSwap: Power',
           'CPU',
           'Cisco Catalyst 9400 Series Routing Processor Module Container',
           'Cisco Catalyst 9400 Series Supervisor 1 Module',
           'USB Container',
           'SATA Container',
           'TenGigabitEthernet4/0/1 Container',
           '10G AOC10M',
           'TenGigabitEthernet4/0/2 Container',
           'TenGigabitEthernet4/0/3 Container',
           'TenGigabitEthernet4/0/4 Container',
           'TenGigabitEthernet4/0/5 Container',
           'TenGigabitEthernet4/0/6 Container',
           'TenGigabitEthernet4/0/7 Container',
           'TenGigabitEthernet4/0/8 Container',
           'FortyGigabitEthernet4/0/9 Container',
           'FortyGigabitEthernet4/0/10 Container',
           'AppGigabitEthernet4/0/1 Container',
           'CPU',
           'Cisco Catalyst 9400 Series Slot',
           'Cisco Catalyst 9400 Series Slot',
           'Cisco Catalyst 9400 Series Power Supply Bay Module Container',
           'Cisco Catalyst 9400 Series 3200W AC Power Supply',
           'Cisco Catalyst 9400 Series Power Supply',
           'FAN 1/1',
           'FAN 1/2',
           'Cisco Catalyst 9400 Series Power Supply Bay Module Container',
           'Cisco Catalyst 9400 Series Power Supply Bay Module Container',
           'Cisco Catalyst 9400 Series Power Supply Bay Module Container',
           'Cisco Catalyst 9400 Series Power Supply Bay Module Container',
           'Cisco Catalyst 9400 Series Power Supply Bay Module Container',
           'Cisco Catalyst 9400 Series Power Supply Bay Module Container',
           'Cisco Catalyst 9400 Series Power Supply Bay Module Container',
           'Cisco Catalyst 9400 Series Fan Tray Bay Module Container',
           'FAN Tray',
           'FAN 17/1',
           'FAN 17/2',
           'FAN 17/3',
           'FAN 17/4',
           'FAN 17/5',
           'FAN 17/6',
           'FAN 17/7',
           'FAN 17/8',
           'FAN 17/9',
           'FAN 17/10',
           'FAN 17/11',
           'FAN 17/12',
           'Cisco Catalyst 9400 Series Slot'],
 'name': ['Chassis',
          'Backplane',
          'slot 1',
          'Slot 1 Linecard',
          'Slot 1 V1: VX1',
          'Slot 1 V1: VX2',
          'Slot 1 V1: VX3',
          'Slot 1 V1: VX4',
          'Slot 1 V1: VX5',
          'Slot 1 V1: VX6',
          'Slot 1 V1: VX7',
          'Slot 1 V1: VX8',
          'Slot 1 V1: VX9',
          'Slot 1 V1: VX10',
          'Slot 1 V1: VX11',
          'Slot1/Outlet',
          'Slot1/Inlet',
          'Slot 1 HotSwap: Volts',
          'Slot 1 HotSwap: Power',
          'GigabitEthernet1/0/1',
          'GigabitEthernet1/0/2',
          'GigabitEthernet1/0/3',
          'GigabitEthernet1/0/4',
          'GigabitEthernet1/0/5',
          'GigabitEthernet1/0/6',
          'GigabitEthernet1/0/7',
          'GigabitEthernet1/0/8',
          'GigabitEthernet1/0/9',
          'GigabitEthernet1/0/10',
          'GigabitEthernet1/0/11',
          'GigabitEthernet1/0/12',
          'GigabitEthernet1/0/13',
          'GigabitEthernet1/0/14',
          'GigabitEthernet1/0/15',
          'GigabitEthernet1/0/16',
          'GigabitEthernet1/0/17',
          'GigabitEthernet1/0/18',
          'GigabitEthernet1/0/19',
          'GigabitEthernet1/0/20',
          'GigabitEthernet1/0/21',
          'GigabitEthernet1/0/22',
          'GigabitEthernet1/0/23',
          'GigabitEthernet1/0/24',
          'GigabitEthernet1/0/25',
          'GigabitEthernet1/0/26',
          'GigabitEthernet1/0/27',
          'GigabitEthernet1/0/28',
          'GigabitEthernet1/0/29',
          'GigabitEthernet1/0/30',
          'GigabitEthernet1/0/31',
          'GigabitEthernet1/0/32',
          'GigabitEthernet1/0/33',
          'GigabitEthernet1/0/34',
          'GigabitEthernet1/0/35',
          'GigabitEthernet1/0/36',
          'GigabitEthernet1/0/37',
          'GigabitEthernet1/0/38',
          'GigabitEthernet1/0/39',
          'GigabitEthernet1/0/40',
          'GigabitEthernet1/0/41',
          'GigabitEthernet1/0/42',
          'GigabitEthernet1/0/43',
          'GigabitEthernet1/0/44',
          'GigabitEthernet1/0/45',
          'GigabitEthernet1/0/46',
          'GigabitEthernet1/0/47',
          'GigabitEthernet1/0/48',
          'slot 2',
          'Slot 2 Linecard',
          'Slot 2 V1: VX1',
          'Slot 2 V1: VX2',
          'Slot 2 V1: VX3',
          'Slot 2 V1: VX4',
          'Slot 2 V1: VX5',
          'Slot 2 V1: VX6',
          'Slot 2 V1: VX7',
          'Slot 2 V1: VX8',
          'Slot 2 V1: VX9',
          'Slot 2 V1: VX10',
          'Slot 2 V1: VX11',
          'Slot2/Outlet',
          'Slot2/Inlet',
          'Slot 2 HotSwap: Volts',
          'Slot 2 HotSwap: Power',
          'GigabitEthernet2/0/1',
          'GigabitEthernet2/0/2',
          'GigabitEthernet2/0/3',
          'GigabitEthernet2/0/4',
          'GigabitEthernet2/0/5',
          'GigabitEthernet2/0/6',
          'GigabitEthernet2/0/7',
          'GigabitEthernet2/0/8',
          'GigabitEthernet2/0/9',
          'GigabitEthernet2/0/10',
          'GigabitEthernet2/0/11',
          'GigabitEthernet2/0/12',
          'GigabitEthernet2/0/13',
          'GigabitEthernet2/0/14',
          'GigabitEthernet2/0/15',
          'GigabitEthernet2/0/16',
          'GigabitEthernet2/0/17',
          'GigabitEthernet2/0/18',
          'GigabitEthernet2/0/19',
          'GigabitEthernet2/0/20',
          'GigabitEthernet2/0/21',
          'GigabitEthernet2/0/22',
          'GigabitEthernet2/0/23',
          'GigabitEthernet2/0/24',
          'GigabitEthernet2/0/25',
          'GigabitEthernet2/0/26',
          'GigabitEthernet2/0/27',
          'GigabitEthernet2/0/28',
          'GigabitEthernet2/0/29',
          'GigabitEthernet2/0/30',
          'GigabitEthernet2/0/31',
          'GigabitEthernet2/0/32',
          'GigabitEthernet2/0/33',
          'GigabitEthernet2/0/34',
          'GigabitEthernet2/0/35',
          'GigabitEthernet2/0/36',
          'GigabitEthernet2/0/37',
          'GigabitEthernet2/0/38',
          'GigabitEthernet2/0/39',
          'GigabitEthernet2/0/40',
          'GigabitEthernet2/0/41',
          'GigabitEthernet2/0/42',
          'GigabitEthernet2/0/43',
          'GigabitEthernet2/0/44',
          'GigabitEthernet2/0/45',
          'GigabitEthernet2/0/46',
          'GigabitEthernet2/0/47',
          'GigabitEthernet2/0/48',
          'slot 3',
          'slot 4',
          'slot 5',
          'slot 6',
          'slot 7',
          'slot R0',
          'Slot 3 Supervisor',
          'Slot 3 USB Container',
          'Slot 3 SATA Container',
          'TenGigabitEthernetContainer3/0/1',
          'TenGigabitEthernet3/0/1',
          'TenGigabitEthernetContainer3/0/2',
          'TenGigabitEthernetContainer3/0/3',
          'TenGigabitEthernetContainer3/0/4',
          'TenGigabitEthernetContainer3/0/5',
          'TenGigabitEthernetContainer3/0/6',
          'TenGigabitEthernetContainer3/0/7',
          'TenGigabitEthernetContainer3/0/8',
          'FortyGigabitEthernetContainer3/0/9',
          'FortyGigabitEthernetContainer3/0/10',
          'Ap3/0/1 Container',
          'Slot3/Coretemp',
          'Slot3/UADP',
          'Slot 3 V1: VX1',
          'Slot 3 V1: VX2',
          'Slot 3 V1: VX3',
          'Slot 3 V1: VX4',
          'Slot 3 V1: VX5',
          'Slot 3 V1: VX6',
          'Slot 3 V1: VX7',
          'Slot 3 V1: VX8',
          'Slot 3 V1: VX9',
          'Slot 3 V1: VX10',
          'Slot 3 V1: VX11',
          'Slot 3 V1: VX12',
          'Slot 3 V1: VX13',
          'Slot 3 V1: VX14',
          'Slot 3 V1: VX15',
          'Slot 3 V1: VX16',
          'Slot3/outlet',
          'Slot3/inlet',
          'Slot 3 HotSwap: Volts',
          'Slot 3 HotSwap: Power',
          'Slot 3 CPU',
          'slot R1',
          'Slot 4 Supervisor',
          'Slot 4 USB Container',
          'Slot 4 SATA Container',
          'TenGigabitEthernetContainer4/0/1',
          'TenGigabitEthernet4/0/1',
          'TenGigabitEthernetContainer4/0/2',
          'TenGigabitEthernetContainer4/0/3',
          'TenGigabitEthernetContainer4/0/4',
          'TenGigabitEthernetContainer4/0/5',
          'TenGigabitEthernetContainer4/0/6',
          'TenGigabitEthernetContainer4/0/7',
          'TenGigabitEthernetContainer4/0/8',
          'FortyGigabitEthernetContainer4/0/9',
          'FortyGigabitEthernetContainer4/0/10',
          'Ap4/0/1 Container',
          'Slot 4 CPU',
          'slot F0',
          'slot F1',
          'PowerSupplyContainer1',
          'PowerSupplyModule1',
          'PowerSupply1',
          'Fan1/1',
          'Fan1/2',
          'PowerSupplyContainer2',
          'PowerSupplyContainer3',
          'PowerSupplyContainer4',
          'PowerSupplyContainer5',
          'PowerSupplyContainer6',
          'PowerSupplyContainer7',
          'PowerSupplyContainer8',
          'FanContainer',
          'FanTray',
          'Fan17/1',
          'Fan17/2',
          'Fan17/3',
          'Fan17/4',
          'Fan17/5',
          'Fan17/6',
          'Fan17/7',
          'Fan17/8',
          'Fan17/9',
          'Fan17/10',
          'Fan17/11',
          'Fan17/12',
          'Internal POE Bay']}
        self.assertEqual(result, expected_output)
