import os
import unittest
from pyats.topology import loader
from genie.libs.sdk.apis.iosxe.platform.get import get_platform_component_firmware_info


class TestGetPlatformComponentFirmwareInfo(unittest.TestCase):

    @classmethod
    def setUpClass(self):
        testbed = f"""
        devices:
          Switch:
            connections:
              defaults:
                class: unicon.Unicon
              a:
                command: mock_device_cli --os iosxe --mock_data_dir {os.path.dirname(__file__)}/mock_data --state connect
                protocol: unknown
            os: iosxe
            platform: cat9k
            type: c9400
        """
        self.testbed = loader.load(testbed)
        self.device = self.testbed.devices['Switch']
        self.device.connect(
            learn_hostname=True,
            init_config_commands=[],
            init_exec_commands=[]
        )

    def test_get_platform_component_firmware_info(self):
        result = get_platform_component_firmware_info(self.device)
        expected_output = {'Ap3/0/1 Container': {'firmware_version': 'NULL'},
 'Ap4/0/1 Container': {'firmware_version': 'NULL'},
 'Backplane': {'firmware_version': 'NULL'},
 'Chassis': {'firmware_version': 'NULL'},
 'Fan1/1': {'firmware_version': 'NULL'},
 'Fan1/2': {'firmware_version': 'NULL'},
 'Fan17/1': {'firmware_version': 'NULL'},
 'Fan17/10': {'firmware_version': 'NULL'},
 'Fan17/11': {'firmware_version': 'NULL'},
 'Fan17/12': {'firmware_version': 'NULL'},
 'Fan17/2': {'firmware_version': 'NULL'},
 'Fan17/3': {'firmware_version': 'NULL'},
 'Fan17/4': {'firmware_version': 'NULL'},
 'Fan17/5': {'firmware_version': 'NULL'},
 'Fan17/6': {'firmware_version': 'NULL'},
 'Fan17/7': {'firmware_version': 'NULL'},
 'Fan17/8': {'firmware_version': 'NULL'},
 'Fan17/9': {'firmware_version': 'NULL'},
 'FanContainer': {'firmware_version': 'NULL'},
 'FanTray': {'firmware_version': 17050302},
 'FortyGigabitEthernetContainer3/0/10': {'firmware_version': 'NULL'},
 'FortyGigabitEthernetContainer3/0/9': {'firmware_version': 'NULL'},
 'FortyGigabitEthernetContainer4/0/10': {'firmware_version': 'NULL'},
 'FortyGigabitEthernetContainer4/0/9': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/1': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/10': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/11': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/12': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/13': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/14': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/15': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/16': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/17': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/18': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/19': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/2': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/20': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/21': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/22': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/23': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/24': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/25': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/26': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/27': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/28': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/29': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/3': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/30': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/31': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/32': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/33': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/34': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/35': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/36': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/37': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/38': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/39': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/4': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/40': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/41': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/42': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/43': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/44': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/45': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/46': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/47': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/48': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/5': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/6': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/7': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/8': {'firmware_version': 'NULL'},
 'GigabitEthernet1/0/9': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/1': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/10': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/11': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/12': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/13': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/14': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/15': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/16': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/17': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/18': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/19': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/2': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/20': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/21': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/22': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/23': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/24': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/25': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/26': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/27': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/28': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/29': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/3': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/30': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/31': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/32': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/33': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/34': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/35': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/36': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/37': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/38': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/39': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/4': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/40': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/41': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/42': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/43': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/44': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/45': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/46': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/47': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/48': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/5': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/6': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/7': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/8': {'firmware_version': 'NULL'},
 'GigabitEthernet2/0/9': {'firmware_version': 'NULL'},
 'Internal POE Bay': {'firmware_version': 'NULL'},
 'PowerSupply1': {'firmware_version': 'NULL'},
 'PowerSupplyContainer1': {'firmware_version': 'NULL'},
 'PowerSupplyContainer2': {'firmware_version': 'NULL'},
 'PowerSupplyContainer3': {'firmware_version': 'NULL'},
 'PowerSupplyContainer4': {'firmware_version': 'NULL'},
 'PowerSupplyContainer5': {'firmware_version': 'NULL'},
 'PowerSupplyContainer6': {'firmware_version': 'NULL'},
 'PowerSupplyContainer7': {'firmware_version': 'NULL'},
 'PowerSupplyContainer8': {'firmware_version': 'NULL'},
 'PowerSupplyModule1': {'firmware_version': '(7.6, 7.0, 6.0)'},
 'Slot 1 Linecard': {'firmware_version': '17.10.1r'},
 'Slot 2 Linecard': {'firmware_version': '17.10.1r'},
 'Slot 3 CPU': {'firmware_version': 'NULL'},
 'Slot 3 SATA Container': {'firmware_version': 'NULL'},
 'Slot 3 Supervisor': {'firmware_version': '17.10.1r'},
 'Slot 3 USB Container': {'firmware_version': 'NULL'},
 'Slot 4 CPU': {'firmware_version': 'NULL'},
 'Slot 4 SATA Container': {'firmware_version': 'NULL'},
 'Slot 4 Supervisor': {'firmware_version': 'NULL'},
 'Slot 4 USB Container': {'firmware_version': 'NULL'},
 'Slot1/Inlet': {'firmware_version': 'NULL'},
 'Slot1/Outlet': {'firmware_version': 'NULL'},
 'Slot2/Inlet': {'firmware_version': 'NULL'},
 'Slot2/Outlet': {'firmware_version': 'NULL'},
 'Slot3/Coretemp': {'firmware_version': 'NULL'},
 'Slot3/UADP': {'firmware_version': 'NULL'},
 'Slot3/inlet': {'firmware_version': 'NULL'},
 'Slot3/outlet': {'firmware_version': 'NULL'},
 'TenGigabitEthernet3/0/1': {'firmware_version': 'NULL'},
 'TenGigabitEthernet4/0/1': {'firmware_version': 'NULL'},
 'TenGigabitEthernetContainer3/0/1': {'firmware_version': 'NULL'},
 'TenGigabitEthernetContainer3/0/2': {'firmware_version': 'NULL'},
 'TenGigabitEthernetContainer3/0/3': {'firmware_version': 'NULL'},
 'TenGigabitEthernetContainer3/0/4': {'firmware_version': 'NULL'},
 'TenGigabitEthernetContainer3/0/5': {'firmware_version': 'NULL'},
 'TenGigabitEthernetContainer3/0/6': {'firmware_version': 'NULL'},
 'TenGigabitEthernetContainer3/0/7': {'firmware_version': 'NULL'},
 'TenGigabitEthernetContainer3/0/8': {'firmware_version': 'NULL'},
 'TenGigabitEthernetContainer4/0/1': {'firmware_version': 'NULL'},
 'TenGigabitEthernetContainer4/0/2': {'firmware_version': 'NULL'},
 'TenGigabitEthernetContainer4/0/3': {'firmware_version': 'NULL'},
 'TenGigabitEthernetContainer4/0/4': {'firmware_version': 'NULL'},
 'TenGigabitEthernetContainer4/0/5': {'firmware_version': 'NULL'},
 'TenGigabitEthernetContainer4/0/6': {'firmware_version': 'NULL'},
 'TenGigabitEthernetContainer4/0/7': {'firmware_version': 'NULL'},
 'TenGigabitEthernetContainer4/0/8': {'firmware_version': 'NULL'},
 'slot 1': {'firmware_version': 'NULL'},
 'slot 2': {'firmware_version': 'NULL'},
 'slot 3': {'firmware_version': 'NULL'},
 'slot 4': {'firmware_version': 'NULL'},
 'slot 5': {'firmware_version': 'NULL'},
 'slot 6': {'firmware_version': 'NULL'},
 'slot 7': {'firmware_version': 'NULL'},
 'slot F0': {'firmware_version': 'NULL'},
 'slot F1': {'firmware_version': 'NULL'},
 'slot R0': {'firmware_version': 'NULL'},
 'slot R1': {'firmware_version': 'NULL'}}
        self.assertEqual(result, expected_output)
