import os
import unittest
from pyats.topology import loader
from genie.libs.sdk.apis.iosxe.platform.get import get_platform_component_type_id_info


class TestGetPlatformComponentTypeIdInfo(unittest.TestCase):

    @classmethod
    def setUpClass(self):
        testbed = f"""
        devices:
          Switch:
            connections:
              defaults:
                class: unicon.Unicon
              a:
                command: mock_device_cli --os iosxe --mock_data_dir {os.path.dirname(__file__)}/mock_data --state connect
                protocol: unknown
            os: iosxe
            platform: cat9k
            type: c9400
        """
        self.testbed = loader.load(testbed)
        self.device = self.testbed.devices['Switch']
        self.device.connect(
            learn_hostname=True,
            init_config_commands=[],
            init_exec_commands=[]
        )

    def test_get_platform_component_type_id_info(self):
        result = get_platform_component_type_id_info(self.device)
        expected_output = {'Ap3/0/1 Container': {'id': 3071,
                       'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'Ap4/0/1 Container': {'id': 4071,
                       'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'Backplane': {'id': 13, 'type': 'openconfig-platform-types:BACKPLANE'},
 'Chassis': {'id': 1, 'type': 'openconfig-platform-types:CHASSIS'},
 'Fan1/1': {'id': 17, 'type': 'openconfig-platform-types:FAN'},
 'Fan1/2': {'id': 18, 'type': 'openconfig-platform-types:FAN'},
 'Fan17/1': {'id': 56, 'type': 'openconfig-platform-types:FAN'},
 'Fan17/10': {'id': 65, 'type': 'openconfig-platform-types:FAN'},
 'Fan17/11': {'id': 66, 'type': 'openconfig-platform-types:FAN'},
 'Fan17/12': {'id': 67, 'type': 'openconfig-platform-types:FAN'},
 'Fan17/2': {'id': 57, 'type': 'openconfig-platform-types:FAN'},
 'Fan17/3': {'id': 58, 'type': 'openconfig-platform-types:FAN'},
 'Fan17/4': {'id': 59, 'type': 'openconfig-platform-types:FAN'},
 'Fan17/5': {'id': 60, 'type': 'openconfig-platform-types:FAN'},
 'Fan17/6': {'id': 61, 'type': 'openconfig-platform-types:FAN'},
 'Fan17/7': {'id': 62, 'type': 'openconfig-platform-types:FAN'},
 'Fan17/8': {'id': 63, 'type': 'openconfig-platform-types:FAN'},
 'Fan17/9': {'id': 64, 'type': 'openconfig-platform-types:FAN'},
 'FanContainer': {'id': 54,
                  'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'FanTray': {'id': 55, 'type': 'openconfig-platform-types:FAN'},
 'FortyGigabitEthernetContainer3/0/10': {'id': 3070,
                                         'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'FortyGigabitEthernetContainer3/0/9': {'id': 3069,
                                        'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'FortyGigabitEthernetContainer4/0/10': {'id': 4070,
                                         'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'FortyGigabitEthernetContainer4/0/9': {'id': 4069,
                                        'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'GigabitEthernet1/0/1': {'id': 1061, 'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/10': {'id': 1070,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/11': {'id': 1071,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/12': {'id': 1072,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/13': {'id': 1073,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/14': {'id': 1074,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/15': {'id': 1075,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/16': {'id': 1076,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/17': {'id': 1077,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/18': {'id': 1078,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/19': {'id': 1079,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/2': {'id': 1062, 'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/20': {'id': 1080,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/21': {'id': 1081,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/22': {'id': 1082,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/23': {'id': 1083,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/24': {'id': 1084,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/25': {'id': 1085,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/26': {'id': 1086,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/27': {'id': 1087,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/28': {'id': 1088,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/29': {'id': 1089,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/3': {'id': 1063, 'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/30': {'id': 1090,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/31': {'id': 1091,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/32': {'id': 1092,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/33': {'id': 1093,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/34': {'id': 1094,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/35': {'id': 1095,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/36': {'id': 1096,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/37': {'id': 1097,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/38': {'id': 1098,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/39': {'id': 1099,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/4': {'id': 1064, 'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/40': {'id': 1100,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/41': {'id': 1101,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/42': {'id': 1102,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/43': {'id': 1103,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/44': {'id': 1104,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/45': {'id': 1105,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/46': {'id': 1106,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/47': {'id': 1107,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/48': {'id': 1108,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/5': {'id': 1065, 'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/6': {'id': 1066, 'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/7': {'id': 1067, 'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/8': {'id': 1068, 'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet1/0/9': {'id': 1069, 'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/1': {'id': 2061, 'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/10': {'id': 2070,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/11': {'id': 2071,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/12': {'id': 2072,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/13': {'id': 2073,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/14': {'id': 2074,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/15': {'id': 2075,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/16': {'id': 2076,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/17': {'id': 2077,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/18': {'id': 2078,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/19': {'id': 2079,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/2': {'id': 2062, 'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/20': {'id': 2080,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/21': {'id': 2081,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/22': {'id': 2082,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/23': {'id': 2083,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/24': {'id': 2084,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/25': {'id': 2085,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/26': {'id': 2086,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/27': {'id': 2087,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/28': {'id': 2088,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/29': {'id': 2089,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/3': {'id': 2063, 'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/30': {'id': 2090,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/31': {'id': 2091,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/32': {'id': 2092,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/33': {'id': 2093,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/34': {'id': 2094,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/35': {'id': 2095,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/36': {'id': 2096,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/37': {'id': 2097,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/38': {'id': 2098,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/39': {'id': 2099,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/4': {'id': 2064, 'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/40': {'id': 2100,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/41': {'id': 2101,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/42': {'id': 2102,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/43': {'id': 2103,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/44': {'id': 2104,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/45': {'id': 2105,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/46': {'id': 2106,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/47': {'id': 2107,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/48': {'id': 2108,
                           'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/5': {'id': 2065, 'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/6': {'id': 2066, 'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/7': {'id': 2067, 'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/8': {'id': 2068, 'type': 'openconfig-platform-types:PORT'},
 'GigabitEthernet2/0/9': {'id': 2069, 'type': 'openconfig-platform-types:PORT'},
 'Internal POE Bay': {'id': 72,
                      'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'PowerSupply1': {'id': 16,
                  'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'PowerSupplyContainer1': {'id': 14,
                           'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'PowerSupplyContainer2': {'id': 19,
                           'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'PowerSupplyContainer3': {'id': 24,
                           'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'PowerSupplyContainer4': {'id': 29,
                           'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'PowerSupplyContainer5': {'id': 34,
                           'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'PowerSupplyContainer6': {'id': 39,
                           'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'PowerSupplyContainer7': {'id': 44,
                           'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'PowerSupplyContainer8': {'id': 49,
                           'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'PowerSupplyModule1': {'id': 15,
                        'type': 'openconfig-platform-types:POWER_SUPPLY'},
 'Slot 1 Linecard': {'id': 1000, 'type': 'openconfig-platform-types:LINECARD'},
 'Slot 2 Linecard': {'id': 2000, 'type': 'openconfig-platform-types:LINECARD'},
 'Slot 3 CPU': {'id': 3051, 'type': 'openconfig-platform-types:CPU'},
 'Slot 3 SATA Container': {'id': 3054,
                           'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'Slot 3 Supervisor': {'id': 3000, 'type': 'openconfig-platform-types:FRU'},
 'Slot 3 USB Container': {'id': 3052,
                          'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'Slot 4 CPU': {'id': 4051, 'type': 'openconfig-platform-types:CPU'},
 'Slot 4 SATA Container': {'id': 4054,
                           'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'Slot 4 Supervisor': {'id': 4000, 'type': 'openconfig-platform-types:FRU'},
 'Slot 4 USB Container': {'id': 4052,
                          'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'Slot1/Inlet': {'id': 1013, 'type': 'openconfig-platform-types:SENSOR'},
 'Slot1/Outlet': {'id': 1012, 'type': 'openconfig-platform-types:SENSOR'},
 'Slot2/Inlet': {'id': 2013, 'type': 'openconfig-platform-types:SENSOR'},
 'Slot2/Outlet': {'id': 2012, 'type': 'openconfig-platform-types:SENSOR'},
 'Slot3/Coretemp': {'id': 3021, 'type': 'openconfig-platform-types:SENSOR'},
 'Slot3/UADP': {'id': 3022, 'type': 'openconfig-platform-types:SENSOR'},
 'Slot3/inlet': {'id': 3040, 'type': 'openconfig-platform-types:SENSOR'},
 'Slot3/outlet': {'id': 3039, 'type': 'openconfig-platform-types:SENSOR'},
 'TenGigabitEthernet3/0/1': {'id': 3073,
                             'type': 'openconfig-platform-types:TRANSCEIVER'},
 'TenGigabitEthernet4/0/1': {'id': 4073,
                             'type': 'openconfig-platform-types:TRANSCEIVER'},
 'TenGigabitEthernetContainer3/0/1': {'id': 3061,
                                      'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'TenGigabitEthernetContainer3/0/2': {'id': 3062,
                                      'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'TenGigabitEthernetContainer3/0/3': {'id': 3063,
                                      'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'TenGigabitEthernetContainer3/0/4': {'id': 3064,
                                      'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'TenGigabitEthernetContainer3/0/5': {'id': 3065,
                                      'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'TenGigabitEthernetContainer3/0/6': {'id': 3066,
                                      'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'TenGigabitEthernetContainer3/0/7': {'id': 3067,
                                      'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'TenGigabitEthernetContainer3/0/8': {'id': 3068,
                                      'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'TenGigabitEthernetContainer4/0/1': {'id': 4061,
                                      'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'TenGigabitEthernetContainer4/0/2': {'id': 4062,
                                      'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'TenGigabitEthernetContainer4/0/3': {'id': 4063,
                                      'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'TenGigabitEthernetContainer4/0/4': {'id': 4064,
                                      'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'TenGigabitEthernetContainer4/0/5': {'id': 4065,
                                      'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'TenGigabitEthernetContainer4/0/6': {'id': 4066,
                                      'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'TenGigabitEthernetContainer4/0/7': {'id': 4067,
                                      'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'TenGigabitEthernetContainer4/0/8': {'id': 4068,
                                      'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'slot 1': {'id': 2, 'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'slot 2': {'id': 3, 'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'slot 3': {'id': 4, 'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'slot 4': {'id': 5, 'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'slot 5': {'id': 6, 'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'slot 6': {'id': 7, 'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'slot 7': {'id': 8, 'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'slot F0': {'id': 11, 'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'slot F1': {'id': 12, 'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'slot R0': {'id': 9, 'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'},
 'slot R1': {'id': 10, 'type': 'cisco-xe-openconfig-platform-ext:CONTAINER'}}
        self.assertEqual(result, expected_output)
