import unittest
from pyats.topology import loader
from genie.libs.sdk.apis.iosxe.poe_transceiver.get import poe_enabled_p4


class TestPoeEnabledP4(unittest.TestCase):

    @classmethod
    def setUpClass(self):
        testbed = """
        devices:
          A2-9300-3M:
            connections:
              defaults:
                class: unicon.Unicon
              a:
                command: mock_device_cli --os iosxe --mock_data_dir mock_data --state connect
                protocol: unknown
            os: iosxe
            platform: iosxe
            type: iosxe
        """
        self.testbed = loader.load(testbed)
        self.device = self.testbed.devices['A2-9300-3M']
        self.device.connect(
            learn_hostname=True,
            init_config_commands=[],
            init_exec_commands=[]
        )

    def test_poe_enabled_p4(self):
        result = poe_enabled_p4(self.device)
        expected_output = {'poe_enabled': ['false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'true',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'true',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false',
                 'false'],
 'poe_intf': ['TwoGigabitEthernet2/0/1',
              'TwoGigabitEthernet2/0/2',
              'TwoGigabitEthernet2/0/3',
              'TwoGigabitEthernet2/0/4',
              'TwoGigabitEthernet2/0/5',
              'TwoGigabitEthernet2/0/6',
              'TwoGigabitEthernet2/0/7',
              'TwoGigabitEthernet2/0/8',
              'TwoGigabitEthernet2/0/9',
              'TwoGigabitEthernet2/0/10',
              'TwoGigabitEthernet2/0/11',
              'TwoGigabitEthernet2/0/12',
              'TwoGigabitEthernet2/0/13',
              'TwoGigabitEthernet2/0/14',
              'TwoGigabitEthernet2/0/15',
              'TwoGigabitEthernet2/0/16',
              'TwoGigabitEthernet2/0/17',
              'TwoGigabitEthernet2/0/18',
              'TwoGigabitEthernet2/0/19',
              'TwoGigabitEthernet2/0/20',
              'TwoGigabitEthernet2/0/21',
              'TwoGigabitEthernet2/0/22',
              'TwoGigabitEthernet2/0/23',
              'TwoGigabitEthernet2/0/24',
              'TwoGigabitEthernet2/0/25',
              'TwoGigabitEthernet2/0/26',
              'TwoGigabitEthernet2/0/27',
              'TwoGigabitEthernet2/0/28',
              'TwoGigabitEthernet2/0/29',
              'TwoGigabitEthernet2/0/30',
              'TwoGigabitEthernet2/0/31',
              'TwoGigabitEthernet2/0/32',
              'TwoGigabitEthernet2/0/33',
              'TwoGigabitEthernet2/0/34',
              'TwoGigabitEthernet2/0/35',
              'TwoGigabitEthernet2/0/36',
              'TenGigabitEthernet2/0/37',
              'TenGigabitEthernet2/0/38',
              'TenGigabitEthernet2/0/39',
              'TenGigabitEthernet2/0/40',
              'TenGigabitEthernet2/0/41',
              'TenGigabitEthernet2/0/42',
              'TenGigabitEthernet2/0/43',
              'TenGigabitEthernet2/0/44',
              'TenGigabitEthernet2/0/45',
              'TenGigabitEthernet2/0/46',
              'TenGigabitEthernet2/0/47',
              'TenGigabitEthernet2/0/48',
              'TwoGigabitEthernet3/0/1',
              'TwoGigabitEthernet3/0/2',
              'TwoGigabitEthernet3/0/3',
              'TwoGigabitEthernet3/0/4',
              'TwoGigabitEthernet3/0/5',
              'TwoGigabitEthernet3/0/6',
              'TwoGigabitEthernet3/0/7',
              'TwoGigabitEthernet3/0/8',
              'TwoGigabitEthernet3/0/9',
              'TwoGigabitEthernet3/0/10',
              'TwoGigabitEthernet3/0/11',
              'TwoGigabitEthernet3/0/12',
              'TwoGigabitEthernet3/0/13',
              'TwoGigabitEthernet3/0/14',
              'TwoGigabitEthernet3/0/15',
              'TwoGigabitEthernet3/0/16',
              'TwoGigabitEthernet3/0/17',
              'TwoGigabitEthernet3/0/18',
              'TwoGigabitEthernet3/0/19',
              'TwoGigabitEthernet3/0/20',
              'TwoGigabitEthernet3/0/21',
              'TwoGigabitEthernet3/0/22',
              'TwoGigabitEthernet3/0/23',
              'TwoGigabitEthernet3/0/24',
              'TwoGigabitEthernet3/0/25',
              'TwoGigabitEthernet3/0/26',
              'TwoGigabitEthernet3/0/27',
              'TwoGigabitEthernet3/0/28',
              'TwoGigabitEthernet3/0/29',
              'TwoGigabitEthernet3/0/30',
              'TwoGigabitEthernet3/0/31',
              'TwoGigabitEthernet3/0/32',
              'TwoGigabitEthernet3/0/33',
              'TwoGigabitEthernet3/0/34',
              'TwoGigabitEthernet3/0/35',
              'TwoGigabitEthernet3/0/36',
              'TenGigabitEthernet3/0/37',
              'TenGigabitEthernet3/0/38',
              'TenGigabitEthernet3/0/39',
              'TenGigabitEthernet3/0/40',
              'TenGigabitEthernet3/0/41',
              'TenGigabitEthernet3/0/42',
              'TenGigabitEthernet3/0/43',
              'TenGigabitEthernet3/0/44',
              'TenGigabitEthernet3/0/45',
              'TenGigabitEthernet3/0/46',
              'TenGigabitEthernet3/0/47',
              'TenGigabitEthernet3/0/48']}
        self.assertEqual(result, expected_output)
