import os
import unittest
from pyats.topology import loader
from genie.libs.sdk.apis.iosxe.telemetry.get import get_telemetry_report_all_kpis


class TestGetTelemetryReportAllKpis(unittest.TestCase):

    @classmethod
    def setUpClass(self):
        testbed = f"""
        devices:
          Switch_48U:
            connections:
              defaults:
                class: unicon.Unicon
              a:
                command: mock_device_cli --os iosxe --mock_data_dir {os.path.dirname(__file__)}/mock_data --state connect
                protocol: unknown
            os: iosxe
            platform: cat9k
            type: c9300
        """
        self.testbed = loader.load(testbed)
        self.device = self.testbed.devices['Switch_48U']
        self.device.connect(
            learn_hostname=True,
            init_config_commands=[],
            init_exec_commands=[]
        )

    def test_get_telemetry_report_all_kpis(self):
        result = get_telemetry_report_all_kpis(self.device, 1680726314)
        expected_output = {'report_id': {1680726314: {'kpi_name': {'ISSU_mode': {'kpi_value': '[{"issu":"ISSU_DISABLED"}]',
                                                       'time_stamp': '04/05/2023 '
                                                                     '20:25:14'},
                                         'LAG_LACP': {'kpi_value': '[]',
                                                      'time_stamp': '04/05/2023 '
                                                                    '20:25:14'},
                                         'TrustSec_global': {'kpi_value': '[{"type":"SGACL_enforcement","enabled":"false"},{"type":"SXP","enabled":"false"}]',
                                                             'time_stamp': '04/05/2023 '
                                                                           '20:25:14'},
                                         'TrustSec_interface': {'kpi_value': '[]',
                                                                'time_stamp': '04/05/2023 '
                                                                              '20:25:14'},
                                         'app_guestshell_cfg': {'kpi_value': '[{"enabled":"false","guestshell":"false"}]',
                                                                'time_stamp': '04/05/2023 '
                                                                              '20:25:14'},
                                         'enabled_features': {'kpi_value': '[{"feature":"<cr>"},{"feature":"boot '
                                                                           'system '
                                                                           'switch '
                                                                           'all '
                                                                           'flash:packages.conf"},{"feature":"call-home"},{"feature":"call-home;contact-email-addr '
                                                                           'WORD"},{"feature":"call-home;profile '
                                                                           'WORD"},{"feature":"call-home;profile '
                                                                           'WORD;active"},{"feature":"call-home;profile '
                                                                           'WORD;destination '
                                                                           'transport-method '
                                                                           'http"},{"feature":"class-map '
                                                                           'match-any '
                                                                           'WORD"},{"feature":"class-map '
                                                                           'match-any '
                                                                           'WORD;description '
                                                                           'LINE"},{"feature":"control-plane"},{"feature":"control-plane;service-policy '
                                                                           'input '
                                                                           'WORD"},{"feature":"crypto '
                                                                           'engine '
                                                                           'compliance '
                                                                           'shield '
                                                                           'disable"},{"feature":"crypto '
                                                                           'pki '
                                                                           'certificate '
                                                                           'chain '
                                                                           'WORD"},{"feature":"crypto '
                                                                           'pki '
                                                                           'certificate '
                                                                           'chain '
                                                                           'WORD;certificate '
                                                                           'ca '
                                                                           'WORD"},{"feature":"crypto '
                                                                           'pki '
                                                                           'certificate '
                                                                           'chain '
                                                                           'WORD;certificate '
                                                                           'self-signed '
                                                                           'WORD"},{"feature":"crypto '
                                                                           'pki '
                                                                           'certificate '
                                                                           'pool"},{"feature":"crypto '
                                                                           'pki '
                                                                           'trustpoint '
                                                                           'WORD"},{"feature":"crypto '
                                                                           'pki '
                                                                           'trustpoint '
                                                                           'WORD;enrollment '
                                                                           'selfsigned"},{"feature":"crypto '
                                                                           'pki '
                                                                           'trustpoint '
                                                                           'WORD;enrollment '
                                                                           'terminal"},{"feature":"crypto '
                                                                           'pki '
                                                                           'trustpoint '
                                                                           'WORD;hash '
                                                                           'sha256"},{"feature":"crypto '
                                                                           'pki '
                                                                           'trustpoint '
                                                                           'WORD;revocation-check '
                                                                           'crl"},{"feature":"crypto '
                                                                           'pki '
                                                                           'trustpoint '
                                                                           'WORD;revocation-check '
                                                                           'none"},{"feature":"crypto '
                                                                           'pki '
                                                                           'trustpoint '
                                                                           'WORD;rsakeypair '
                                                                           'WORD"},{"feature":"crypto '
                                                                           'pki '
                                                                           'trustpoint '
                                                                           'WORD;subject-name '
                                                                           'LINE"},{"feature":"diagnostic '
                                                                           'bootup '
                                                                           'level '
                                                                           'minimal"},{"feature":"end"},{"feature":"hostname '
                                                                           'WORD"},{"feature":"hw-module '
                                                                           'switch '
                                                                           '<1-16> '
                                                                           'upoe-plus"},{"feature":"interface '
                                                                           'AppGigabitEthernet '
                                                                           '<0-16> '
                                                                           '<0-1> '
                                                                           '<0-1>"},{"feature":"interface '
                                                                           'FortyGigabitEthernet '
                                                                           '<0-16> '
                                                                           '<0-1> '
                                                                           '<0-2>"},{"feature":"interface '
                                                                           'GigabitEthernet '
                                                                           '<0-16> '
                                                                           '<0-0>"},{"feature":"interface '
                                                                           'GigabitEthernet '
                                                                           '<0-16> '
                                                                           '<0-0>;ip '
                                                                           'address '
                                                                           'A.B.C.D '
                                                                           'A.B.C.D"},{"feature":"interface '
                                                                           'GigabitEthernet '
                                                                           '<0-16> '
                                                                           '<0-0>;negotiation '
                                                                           'auto"},{"feature":"interface '
                                                                           'GigabitEthernet '
                                                                           '<0-16> '
                                                                           '<0-0>;vrf '
                                                                           'forwarding '
                                                                           'Mgmt-vrf"},{"feature":"interface '
                                                                           'GigabitEthernet '
                                                                           '<0-16> '
                                                                           '<0-1> '
                                                                           '<0-48>"},{"feature":"interface '
                                                                           'GigabitEthernet '
                                                                           '<0-16> '
                                                                           '<0-1> '
                                                                           '<0-48>;ip '
                                                                           'address '
                                                                           'A.B.C.D '
                                                                           'A.B.C.D"},{"feature":"interface '
                                                                           'GigabitEthernet '
                                                                           '<0-16> '
                                                                           '<0-1> '
                                                                           '<0-48>;no '
                                                                           'switchport"},{"feature":"interface '
                                                                           'TenGigabitEthernet '
                                                                           '<0-16> '
                                                                           '<0-1> '
                                                                           '<0-8>"},{"feature":"interface '
                                                                           'TwentyFiveGigE '
                                                                           '<0-16> '
                                                                           '<0-1> '
                                                                           '<0-2>"},{"feature":"interface '
                                                                           'Vlan '
                                                                           '<1-4094>"},{"feature":"interface '
                                                                           'Vlan '
                                                                           '<1-4094>;no '
                                                                           'ip '
                                                                           'address"},{"feature":"interface '
                                                                           'Vlan '
                                                                           '<1-4094>;shutdown"},{"feature":"ip '
                                                                           'domain '
                                                                           'name '
                                                                           'WORD"},{"feature":"ip '
                                                                           'forward-protocol '
                                                                           'nd"},{"feature":"ip '
                                                                           'http '
                                                                           'authentication '
                                                                           'local"},{"feature":"ip '
                                                                           'http '
                                                                           'secure-server"},{"feature":"ip '
                                                                           'http '
                                                                           'server"},{"feature":"ip '
                                                                           'name-server '
                                                                           'A.B.C.D '
                                                                           'A.B.C.D '
                                                                           'A.B.C.D '
                                                                           'A.B.C.D"},{"feature":"ip '
                                                                           'route '
                                                                           'A.B.C.D '
                                                                           'A.B.C.D '
                                                                           'A.B.C.D"},{"feature":"ip '
                                                                           'route '
                                                                           'vrf '
                                                                           'WORD '
                                                                           'A.B.C.D '
                                                                           'A.B.C.D '
                                                                           'A.B.C.D"},{"feature":"ip '
                                                                           'ssh '
                                                                           'bulk-mode '
                                                                           '<131072-1073741824>"},{"feature":"ip '
                                                                           'tftp '
                                                                           'source-interface '
                                                                           'GigabitEthernet '
                                                                           '<0-16> '
                                                                           '<0-0>"},{"feature":"license '
                                                                           'boot '
                                                                           'level '
                                                                           'network-advantage '
                                                                           'addon '
                                                                           'dna-advantage"},{"feature":"license '
                                                                           'smart '
                                                                           'transport '
                                                                           'smart"},{"feature":"license '
                                                                           'smart '
                                                                           'url '
                                                                           'WORD"},{"feature":"license '
                                                                           'smart '
                                                                           'url '
                                                                           'smart '
                                                                           'WORD"},{"feature":"line '
                                                                           'console '
                                                                           '<0-0>"},{"feature":"line '
                                                                           'console '
                                                                           '<0-0>;exec-timeout '
                                                                           '<0-35791> '
                                                                           '<0-2147483>"},{"feature":"line '
                                                                           'console '
                                                                           '<0-0>;speed '
                                                                           '<0-4294967295>"},{"feature":"line '
                                                                           'console '
                                                                           '<0-0>;stopbits '
                                                                           '1"},{"feature":"line '
                                                                           'vty '
                                                                           '<0-98> '
                                                                           '<1-98>"},{"feature":"line '
                                                                           'vty '
                                                                           '<0-98> '
                                                                           '<1-98>;exec-timeout '
                                                                           '<0-35791> '
                                                                           '<0-2147483>"},{"feature":"line '
                                                                           'vty '
                                                                           '<0-98> '
                                                                           '<1-98>;length '
                                                                           '<0-512>"},{"feature":"line '
                                                                           'vty '
                                                                           '<0-98> '
                                                                           '<1-98>;login"},{"feature":"line '
                                                                           'vty '
                                                                           '<0-98> '
                                                                           '<1-98>;transport '
                                                                           'input '
                                                                           'ssh"},{"feature":"line '
                                                                           'vty '
                                                                           '<0-98> '
                                                                           '<6-98>"},{"feature":"line '
                                                                           'vty '
                                                                           '<0-98> '
                                                                           '<6-98>;login"},{"feature":"line '
                                                                           'vty '
                                                                           '<0-98> '
                                                                           '<6-98>;transport '
                                                                           'input '
                                                                           'ssh"},{"feature":"login '
                                                                           'on-success '
                                                                           'log"},{"feature":"memory '
                                                                           'free '
                                                                           'low-watermark '
                                                                           'processor '
                                                                           '<1-3994575>"},{"feature":"platform '
                                                                           'punt-keepalive '
                                                                           'disable-kernel-core"},{"feature":"policy-map '
                                                                           'WORD"},{"feature":"quit"},{"feature":"redundancy"},{"feature":"redundancy;mode '
                                                                           'sso"},{"feature":"service '
                                                                           'call-home"},{"feature":"service '
                                                                           'internal"},{"feature":"service '
                                                                           'timestamps '
                                                                           'debug '
                                                                           'datetime '
                                                                           'msec"},{"feature":"service '
                                                                           'timestamps '
                                                                           'log '
                                                                           'datetime '
                                                                           'msec"},{"feature":"spanning-tree '
                                                                           'extend '
                                                                           'system-id"},{"feature":"spanning-tree '
                                                                           'mode '
                                                                           'rapid-pvst"},{"feature":"switch '
                                                                           '<1-16> '
                                                                           'provision '
                                                                           'c9300-48uxm '
                                                                           'c9300-48u"},{"feature":"transceiver '
                                                                           'type '
                                                                           'all"},{"feature":"transceiver '
                                                                           'type '
                                                                           'all;monitoring"},{"feature":"version '
                                                                           '<1-2147483647> '
                                                                           '. '
                                                                           '<1-2147483647>"},{"feature":"vlan '
                                                                           'WORD"},{"feature":"vrf '
                                                                           'definition '
                                                                           'WORD"},{"feature":"vrf '
                                                                           'definition '
                                                                           'WORD;address-family '
                                                                           'ipv4"},{"feature":"vrf '
                                                                           'definition '
                                                                           'WORD;address-family '
                                                                           'ipv4;exit-address-family"},{"feature":"vrf '
                                                                           'definition '
                                                                           'WORD;address-family '
                                                                           'ipv6"},{"feature":"vrf '
                                                                           'definition '
                                                                           'WORD;address-family '
                                                                           'ipv6;exit-address-family"},{"feature":"vtp '
                                                                           'domain '
                                                                           'WORD"},{"feature":"vtp '
                                                                           'mode '
                                                                           'transparent"}]',
                                                              'time_stamp': '04/05/2023 '
                                                                            '20:25:14'},
                                         'global_CPU_usage': {'kpi_value': '[{"Max":0,"Min":0,"Avg":0}]',
                                                              'time_stamp': '04/05/2023 '
                                                                            '20:25:14'},
                                         'hardware_inventory': {'kpi_value': '[{"CN":"Switch2","SN":"FCW2137L0E2","PID":"C9300-48U"},{"CN":"c93xx '
                                                                             'Stack","SN":"FCW2137L0E2","PID":"C9300-48U"},{"CN":"PowerSupply2/B","SN":"DCA2210G3R5","PID":"PWR-C1-715WAC"}]',
                                                                'time_stamp': '04/05/2023 '
                                                                              '20:25:14'},
                                         'hardware_inventory_port_count': {'kpi_value': '[{"PID":"C3850-NM-4-10G","COUNT":1}]',
                                                                           'time_stamp': '04/05/2023 '
                                                                                         '20:25:14'},
                                         'install_mode': {'kpi_value': '[{"boot_mode":"INSTALL_BOOT_MODE_INSTALL"}]',
                                                          'time_stamp': '04/05/2023 '
                                                                        '20:25:14'},
                                         'ipv6': {'kpi_value': '[{"enabled":"false"}]',
                                                  'time_stamp': '04/05/2023 '
                                                                '20:25:14'},
                                         'memory_usage': {'kpi_value': '[{"Max":2963508,"Min":2960960,"Avg":2962234}]',
                                                          'time_stamp': '04/05/2023 '
                                                                        '20:25:14'},
                                         'nat': {'kpi_value': '[{"enabled":"false"}]',
                                                 'time_stamp': '04/05/2023 '
                                                               '20:25:14'},
                                         'software_packages': {'kpi_value': '[]',
                                                               'time_stamp': '04/05/2023 '
                                                                             '20:25:14'}}}}}
        self.assertEqual(result, expected_output)
