import unittest
from pyats.topology import loader
from genie.libs.sdk.apis.nxos.interface.get import get_interface_names


class TestGetInterfaceNames(unittest.TestCase):

    @classmethod
    def setUpClass(self):
        testbed = """
        devices:
          R3_nx:
            connections:
              defaults:
                class: unicon.Unicon
              a:
                command: mock_device_cli --os nxos --mock_data_dir mock_data --state connect
                protocol: unknown
            os: nxos
            platform: n9kv
            type: NX-OSv 9000
        """
        self.testbed = loader.load(testbed)
        self.device = self.testbed.devices['R3_nx']
        self.device.connect(
            learn_hostname=True,
            init_config_commands=[],
            init_exec_commands=[]
        )

    def test_get_interface_names(self):
        result = get_interface_names(self.device)
        expected_output = ['mgmt0',
 'Ethernet1/1',
 'Ethernet1/1.90',
 'Ethernet1/1.110',
 'Ethernet1/1.115',
 'Ethernet1/1.120',
 'Ethernet1/1.390',
 'Ethernet1/1.410',
 'Ethernet1/1.415',
 'Ethernet1/1.420',
 'Ethernet1/2',
 'Ethernet1/2.90',
 'Ethernet1/2.110',
 'Ethernet1/2.115',
 'Ethernet1/2.120',
 'Ethernet1/2.390',
 'Ethernet1/2.410',
 'Ethernet1/2.415',
 'Ethernet1/2.420',
 'Ethernet1/3',
 'Ethernet1/4',
 'Ethernet1/5',
 'Ethernet1/6',
 'Ethernet1/7',
 'Ethernet1/8',
 'Ethernet1/9',
 'Ethernet1/10',
 'Ethernet1/11',
 'Ethernet1/12',
 'Ethernet1/13',
 'Ethernet1/14',
 'Ethernet1/15',
 'Ethernet1/16',
 'Ethernet1/17',
 'Ethernet1/18',
 'Ethernet1/19',
 'Ethernet1/20',
 'Ethernet1/21',
 'Ethernet1/22',
 'Ethernet1/23',
 'Ethernet1/24',
 'Ethernet1/25',
 'Ethernet1/26',
 'Ethernet1/27',
 'Ethernet1/28',
 'Ethernet1/29',
 'Ethernet1/30',
 'Ethernet1/31',
 'Ethernet1/32',
 'Ethernet1/33',
 'Ethernet1/34',
 'Ethernet1/35',
 'Ethernet1/36',
 'Ethernet1/37',
 'Ethernet1/38',
 'Ethernet1/39',
 'Ethernet1/40',
 'Ethernet1/41',
 'Ethernet1/42',
 'Ethernet1/43',
 'Ethernet1/44',
 'Ethernet1/45',
 'Ethernet1/46',
 'Ethernet1/47',
 'Ethernet1/48',
 'Ethernet1/49',
 'Ethernet1/50',
 'Ethernet1/51',
 'Ethernet1/52',
 'Ethernet1/53',
 'Ethernet1/54',
 'Ethernet1/55',
 'Ethernet1/56',
 'Ethernet1/57',
 'Ethernet1/58',
 'Ethernet1/59',
 'Ethernet1/60',
 'Ethernet1/61',
 'Ethernet1/62',
 'Ethernet1/63',
 'Ethernet1/64',
 'Ethernet1/65',
 'Ethernet1/66',
 'Ethernet1/67',
 'Ethernet1/68',
 'Ethernet1/69',
 'Ethernet1/70',
 'Ethernet1/71',
 'Ethernet1/72',
 'Ethernet1/73',
 'Ethernet1/74',
 'Ethernet1/75',
 'Ethernet1/76',
 'Ethernet1/77',
 'Ethernet1/78',
 'Ethernet1/79',
 'Ethernet1/80',
 'Ethernet1/81',
 'Ethernet1/82',
 'Ethernet1/83',
 'Ethernet1/84',
 'Ethernet1/85',
 'Ethernet1/86',
 'Ethernet1/87',
 'Ethernet1/88',
 'Ethernet1/89',
 'Ethernet1/90',
 'Ethernet1/91',
 'Ethernet1/92',
 'Ethernet1/93',
 'Ethernet1/94',
 'Ethernet1/95',
 'Ethernet1/96',
 'Ethernet1/97',
 'Ethernet1/98',
 'Ethernet1/99',
 'Ethernet1/100',
 'Ethernet1/101',
 'Ethernet1/102',
 'Ethernet1/103',
 'Ethernet1/104',
 'Ethernet1/105',
 'Ethernet1/106',
 'Ethernet1/107',
 'Ethernet1/108',
 'Ethernet1/109',
 'Ethernet1/110',
 'Ethernet1/111',
 'Ethernet1/112',
 'Ethernet1/113',
 'Ethernet1/114',
 'Ethernet1/115',
 'Ethernet1/116',
 'Ethernet1/117',
 'Ethernet1/118',
 'Ethernet1/119',
 'Ethernet1/120',
 'Ethernet1/121',
 'Ethernet1/122',
 'Ethernet1/123',
 'Ethernet1/124',
 'Ethernet1/125',
 'Ethernet1/126',
 'Ethernet1/127',
 'Ethernet1/128',
 'Port-channel13',
 'Port-channel23',
 'Loopback0',
 'Loopback300']
        self.assertEqual(result, expected_output)
