import unittest
from pyats.topology import loader
from genie.libs.sdk.apis.nxos.interface.get import get_interfaces_status


class TestGetInterfacesStatus(unittest.TestCase):

    @classmethod
    def setUpClass(self):
        testbed = """
        devices:
          R3_nx:
            connections:
              defaults:
                class: unicon.Unicon
              a:
                command: mock_device_cli --os nxos --mock_data_dir mock_data --state connect
                protocol: unknown
            os: nxos
            platform: n9kv
            type: NX-OSv 9000
        """
        self.testbed = loader.load(testbed)
        self.device = self.testbed.devices['R3_nx']
        self.device.connect(
            learn_hostname=True,
            init_config_commands=[],
            init_exec_commands=[]
        )

    def test_get_interfaces_status(self):
        result = get_interfaces_status(self.device)
        expected_output = {'Ethernet1/1': 'Up',
 'Ethernet1/1.90': 'Up',
 'Ethernet1/1.110': 'Up',
 'Ethernet1/1.115': 'Up',
 'Ethernet1/1.120': 'Up',
 'Ethernet1/1.390': 'Up',
 'Ethernet1/1.410': 'Up',
 'Ethernet1/1.415': 'Up',
 'Ethernet1/1.420': 'Up',
 'Ethernet1/2': 'Up',
 'Ethernet1/2.90': 'Up',
 'Ethernet1/2.110': 'Up',
 'Ethernet1/2.115': 'Up',
 'Ethernet1/2.120': 'Up',
 'Ethernet1/2.390': 'Up',
 'Ethernet1/2.410': 'Up',
 'Ethernet1/2.415': 'Up',
 'Ethernet1/2.420': 'Up',
 'Ethernet1/3': 'Up',
 'Ethernet1/4': 'Up',
 'Ethernet1/5': 'Up',
 'Ethernet1/6': 'Up',
 'Ethernet1/7': 'Down',
 'Ethernet1/8': 'Down',
 'Ethernet1/9': 'Down',
 'Ethernet1/10': 'Down',
 'Ethernet1/11': 'Down',
 'Ethernet1/12': 'Down',
 'Ethernet1/13': 'Down',
 'Ethernet1/14': 'Down',
 'Ethernet1/15': 'Down',
 'Ethernet1/16': 'Down',
 'Ethernet1/17': 'Down',
 'Ethernet1/18': 'Down',
 'Ethernet1/19': 'Down',
 'Ethernet1/20': 'Down',
 'Ethernet1/21': 'Down',
 'Ethernet1/22': 'Down',
 'Ethernet1/23': 'Down',
 'Ethernet1/24': 'Down',
 'Ethernet1/25': 'Down',
 'Ethernet1/26': 'Down',
 'Ethernet1/27': 'Down',
 'Ethernet1/28': 'Down',
 'Ethernet1/29': 'Down',
 'Ethernet1/30': 'Down',
 'Ethernet1/31': 'Down',
 'Ethernet1/32': 'Down',
 'Ethernet1/33': 'Down',
 'Ethernet1/34': 'Down',
 'Ethernet1/35': 'Down',
 'Ethernet1/36': 'Down',
 'Ethernet1/37': 'Down',
 'Ethernet1/38': 'Down',
 'Ethernet1/39': 'Down',
 'Ethernet1/40': 'Down',
 'Ethernet1/41': 'Down',
 'Ethernet1/42': 'Down',
 'Ethernet1/43': 'Down',
 'Ethernet1/44': 'Down',
 'Ethernet1/45': 'Down',
 'Ethernet1/46': 'Down',
 'Ethernet1/47': 'Down',
 'Ethernet1/48': 'Down',
 'Ethernet1/49': 'Down',
 'Ethernet1/50': 'Down',
 'Ethernet1/51': 'Down',
 'Ethernet1/52': 'Down',
 'Ethernet1/53': 'Down',
 'Ethernet1/54': 'Down',
 'Ethernet1/55': 'Down',
 'Ethernet1/56': 'Down',
 'Ethernet1/57': 'Down',
 'Ethernet1/58': 'Down',
 'Ethernet1/59': 'Down',
 'Ethernet1/60': 'Down',
 'Ethernet1/61': 'Down',
 'Ethernet1/62': 'Down',
 'Ethernet1/63': 'Down',
 'Ethernet1/64': 'Down',
 'Ethernet1/65': 'Down',
 'Ethernet1/66': 'Down',
 'Ethernet1/67': 'Down',
 'Ethernet1/68': 'Down',
 'Ethernet1/69': 'Down',
 'Ethernet1/70': 'Down',
 'Ethernet1/71': 'Down',
 'Ethernet1/72': 'Down',
 'Ethernet1/73': 'Down',
 'Ethernet1/74': 'Down',
 'Ethernet1/75': 'Down',
 'Ethernet1/76': 'Down',
 'Ethernet1/77': 'Down',
 'Ethernet1/78': 'Down',
 'Ethernet1/79': 'Down',
 'Ethernet1/80': 'Down',
 'Ethernet1/81': 'Down',
 'Ethernet1/82': 'Down',
 'Ethernet1/83': 'Down',
 'Ethernet1/84': 'Down',
 'Ethernet1/85': 'Down',
 'Ethernet1/86': 'Down',
 'Ethernet1/87': 'Down',
 'Ethernet1/88': 'Down',
 'Ethernet1/89': 'Down',
 'Ethernet1/90': 'Down',
 'Ethernet1/91': 'Down',
 'Ethernet1/92': 'Down',
 'Ethernet1/93': 'Down',
 'Ethernet1/94': 'Down',
 'Ethernet1/95': 'Down',
 'Ethernet1/96': 'Down',
 'Ethernet1/97': 'Down',
 'Ethernet1/98': 'Down',
 'Ethernet1/99': 'Down',
 'Ethernet1/100': 'Down',
 'Ethernet1/101': 'Down',
 'Ethernet1/102': 'Down',
 'Ethernet1/103': 'Down',
 'Ethernet1/104': 'Down',
 'Ethernet1/105': 'Down',
 'Ethernet1/106': 'Down',
 'Ethernet1/107': 'Down',
 'Ethernet1/108': 'Down',
 'Ethernet1/109': 'Down',
 'Ethernet1/110': 'Down',
 'Ethernet1/111': 'Down',
 'Ethernet1/112': 'Down',
 'Ethernet1/113': 'Down',
 'Ethernet1/114': 'Down',
 'Ethernet1/115': 'Down',
 'Ethernet1/116': 'Down',
 'Ethernet1/117': 'Down',
 'Ethernet1/118': 'Down',
 'Ethernet1/119': 'Down',
 'Ethernet1/120': 'Down',
 'Ethernet1/121': 'Down',
 'Ethernet1/122': 'Down',
 'Ethernet1/123': 'Down',
 'Ethernet1/124': 'Down',
 'Ethernet1/125': 'Down',
 'Ethernet1/126': 'Down',
 'Ethernet1/127': 'Down',
 'Ethernet1/128': 'Down'}
        self.assertEqual(result, expected_output)
